module.exports = defineTest({
	description: 'generates multiple output files, only one of which is minified',
	command: 'rollup -c'
});
